Crate vregex

Crate vregex 

Structs

RegEx
RegEx provides methods to construct a regular expression from a pattern string and perform common operations such as matching and searching within input text.

Enums

Error