pub struct RegEx { /* private fields */ }Expand description
RegEx provides methods to construct a regular expression from a pattern string and
perform common operations such as matching and searching within input text.
Internally, it compiles the pattern into an NFA.
Implementations
Sourceimpl RegEx
impl RegEx
Sourcepub fn from_pattern(regex: &str) -> Result<Self, Error>
pub fn from_pattern(regex: &str) -> Result<Self, Error>
Parses the given pattern and returns a compiled RegEx.
Errors
Returns an error if the pattern contains invalid syntax.
Supported Syntax
.matches any single character|for alternate:a|bmatchesaorb[]for character classes:[abc]matches any character in the set- Use
^at the beginning to negate:[^abc]matches any character excepta,b, orc
Predefined character classes:
\d,\Dfor digits\l,\Lfor lowercase letters\u,\Ufor uppercase letters\s,\Sfor whitespace